@@ -1,6 +1,6 @@
 from datetime import datetime
 
-from UPC import UPC
+from pgsaw.UPC import UPC
 
 
 class Item:
